==> djangoplus-0.0.38.tar.gz: djangoplus-0.0.38/djangoplus/docs/utils.py <==
# -*- coding: utf-8 -*-
import re
import json
import inspect
from django.apps import apps
from django.utils.translation import ugettext as _
from djangoplus.utils.metadata import get_metadata, get_fiendly_name


def extract_documentation(model):
    s = ''
    if model.__doc__:
        if not model.__doc__.decode('utf-8').startswith(u'%s(' % model.__name__):
            s = model.__doc__.decode('utf-8')
            s = s.replace(u'\t', u'').replace(u'\n', u'').replace(u'  ', u' ').strip()
    return s


def extract_exception_messages(function):
    messages = []
    if function:
        code = unicode((''.join(inspect.getsourcelines(function)[0])).decode('utf-8'))
        for message in re.findall('ValidationError.*\(.*\)', code):
            messages.append(
                message[message.index('(') + 1:message.index(')') - 1].replace(u'u\'', '').replace(u'"', ''))
    return messages


def get_search_fields(model):
    l = []
    lookups = get_metadata(model, 'search_fields', [])
    if lookups:
        for i, lookup in enumerate(lookups):
            l.append('"%s"' % get_fiendly_name(model, lookup).lower())
            if i > 0 and i == len(lookups) - 2:
                l.append(_(' or '))
            elif i < len(lookups) - 2:
                l.append(',')
    return ''.join(l)


def get_list_filter(model):
    l = []
    lookups = get_metadata(model, 'list_filter', [])
    if lookups:
        for i, lookup in enumerate(lookups):
            l.append('"%s"' % get_fiendly_name(model, lookup).lower())
            if i > 0 and i == len(lookups) - 2:
                l.append(_(' or '))
            elif i < len(lookups) - 2:
                l.append(', ')
    return ''.join(l)


def get_list_display(model):
    l = []
    lookups = get_metadata(model, 'list_display', [])
    for i, lookup in enumerate(lookups):
        if i > 0:
            if i == len(lookups) - 1:
                l.append(_(' and '))
            else:
                l.append(', ')
        l.append('"%s"' % get_fiendly_name(model, lookup).lower())
    return ''.join(l)



def documentation(as_json=False):

    for app_config in apps.get_app_configs():
        description = app_config.module.__doc__

==> djangoplus-0.0.41.tar.gz: djangoplus-0.0.41/djangoplus/docs/utils.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import re
import json
import inspect
from django.apps import apps
from django.utils.translation import ugettext as _
from djangoplus.utils.metadata import get_metadata, get_fiendly_name


def extract_documentation(model):
    s = ''
    if model.__doc__:
        if not model.__doc__.decode('utf-8').startswith('{}('.format(model.__name__)):
            s = model.__doc__.decode('utf-8')
            s = s.replace('\t', '').replace('\n', '').replace('  ', ' ').strip()
    return s


def extract_exception_messages(function):
    messages = []
    if function:
        code = unicode((''.join(inspect.getsourcelines(function)[0])).decode('utf-8'))
        for message in re.findall('ValidationError.*\(.*\)', code):
            messages.append(
                message[message.index('(') + 1:message.index(')') - 1].replace('u\'', '').replace('"', ''))
    return messages


def get_search_fields(model):
    l = []
    lookups = get_metadata(model, 'search_fields', [])
    if lookups:
        for i, lookup in enumerate(lookups):
            l.append('"{}"'.format(get_fiendly_name(model, lookup).lower()))
            if i > 0 and i == len(lookups) - 2:
                l.append(_(' or '))
            elif i < len(lookups) - 2:
                l.append(',')
    return ''.join(l)


def get_list_filter(model):
    l = []
    lookups = get_metadata(model, 'list_filter', [])
    if lookups:
        for i, lookup in enumerate(lookups):
            l.append('"{}"'.format(get_fiendly_name(model, lookup).lower()))
            if i > 0 and i == len(lookups) - 2:
                l.append(_(' or '))
            elif i < len(lookups) - 2:
                l.append(', ')
    return ''.join(l)


def get_list_display(model):
    l = []
    lookups = get_metadata(model, 'list_display', [])
    for i, lookup in enumerate(lookups):
        if i > 0:
            if i == len(lookups) - 1:
                l.append(_(' and '))
            else:
                l.append(', ')
        l.append('"{}"'.format(get_fiendly_name(model, lookup).lower()))
    return ''.join(l)



def documentation(as_json=False):

    for app_config in apps.get_app_configs():
        description = app_config.module.__doc__
